"use strict";

var _eslint = require("eslint");

var _noJestImport = _interopRequireDefault(require("../no-jest-import"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const RuleTester = _eslint.RuleTester;
const ruleTester = new RuleTester({
  parser: '@typescript-eslint/parser',
  parserOptions: {
    ecmaVersion: 6
  }
});
ruleTester.run('no-jest-import', _noJestImport.default, {
  valid: [{
    code: 'import something from "something"',
    parserOptions: {
      sourceType: 'module'
    }
  }, 'require("somethingElse")', 'require()', 'entirelyDifferent(fn)'],
  invalid: [{
    code: 'require("jest")',
    errors: [{
      endColumn: 15,
      column: 9,
      messageId: 'unexpectedImport'
    }]
  }, {
    code: 'import jest from "jest"',
    parserOptions: {
      sourceType: 'module'
    },
    errors: [{
      endColumn: 24,
      column: 18,
      messageId: 'unexpectedImport'
    }]
  }, {
    code: 'var jest = require("jest")',
    errors: [{
      endColumn: 26,
      column: 20,
      messageId: 'unexpectedImport'
    }]
  }, {
    code: 'import {jest as test} from "jest"',
    parserOptions: {
      sourceType: 'module'
    },
    errors: [{
      endColumn: 34,
      column: 28,
      messageId: 'unexpectedImport'
    }]
  }, {
    code: 'const jest = require("jest")',
    parserOptions: {
      sourceType: 'module'
    },
    errors: [{
      endColumn: 28,
      column: 22,
      messageId: 'unexpectedImport'
    }]
  }]
});